@@ -48,6 +48,11 @@ def docs():
         "[21] ssap.bar02(df, parameter_x, parameter_category, title)\n"
         "[22] ssap.bar03(df, parameter_x, parameter_y, method, title) | (method(sum/mean/median,max,min,var))\n"
         "[23] ssap.bar04(df, parameter_x, parameter_y, method, title) | method(std_err,ci)\n"
+        "[24] ssap.pie(df, parameter, title)\n"
+        "[25] ssap.scatter01(df, parameter_x, parameter_y, title)\n"
+        "[26] ssap.scatter02(df, parameter_x, parameter_y, parameter_z, bubblesize, title)\n"
+        "[27] ssap.scatter03(df, parameter_x, parameter_y, category, title)\n"
+        "[28] ssap.map()\n"
     )
     # explain details:
     # print(
@@ -89,9 +94,9 @@ def cmd():
         "[5] df1 = df.loc[df['parameter name']==xxx] | 'filter dataset with conditions'\n"
         "[6] df.dropna(axis=1) | 'remove nan'\n"
         "[7] df = df.rename(columns = {'engine serial number':'esn'}) | 'change column name'\n"
-        "[8] df2.sort_values(by=['xxx'],inplace=True) | 'sort values'"
-        "[9] set(df) | 'remove duplicate for one parameter'"
-        "[10] df['new column'] = df['existing column'] + 100 | 'add a new column' "
+        "[8] df2.sort_values(by=['xxx'],inplace=True) | 'sort values'\n"
+        "[9] set(df) | 'remove duplicate for one parameter'\n"
+        "[10] df['new column'] = df['existing column'] + 100 | 'add a new column' \n"
     )
 
 
@@ -833,8 +838,6 @@ def bar04(df, parameter_x, parameter_y, method, title):  # single category
     plt.show()
 
 
-
-# >>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>> [to be validated.]
 # pie chart - one category parameter.
 def pie(df, parameter, title):
     import matplotlib.pyplot as plt
@@ -969,9 +972,69 @@ def map():
     return m
 
 
+
+
+
+# >>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>> [to be validated.]
 # map with value method(max,min,mean,median,sum,std_err)
+def map01(df, province, parameter_x, method):
+    import matplotlib.pyplot as plt
+    import numpy as np
+    import folium
+    import pandas as pd
 
+    df = df
+    df1 = df[[province, parameter_x]]
 
+    category = list(set(df1[province]))
+    value = []
+
+    for i in category:
+        temp = df[parameter_x].loc[df[province] == i]
+        temp = temp.tolist()
+
+        if method == 'sum':
+            temp1 = np.sum(temp)
+        elif method == 'median':
+            temp1 = np.median(temp)
+        elif method == 'std':
+            temp1 = np.std(temp)
+        elif method == 'max':
+            temp1 = np.max(temp)
+        elif method == 'min':
+            temp1 = np.min(temp)
+        else:
+            temp1 = np.var(temp)
+
+        value.append(temp1)
+
+    dfnew = pd.DataFrame(
+        {
+            'province': category,
+            'value': value,
+        }
+    )
+
+    print(dfnew)
+
+    pdsmap = folium.Map(location=[35, 120], zoom_start=4)
+    pdsmap.choropleth(
+        geo_data=open('C:/Users/lx379/Desktop/ssappoc/china.json', encoding='utf-8-sig').read(),
+        data=dfnew,
+        columns=['province', 'value'],
+        key_on='feature.properties.name',
+        fill_color='YlOrBr',
+        nan_fill_color='lightgrey',
+        fill_opacity=0.8,
+        nan_fill_opacity=0.1,
+        line_color='grey',
+        line_opacity=0.2,
+        legend_name='[PDS_Map] distribution for: ' + parameter_x + ' (' + method + ')',
+        highlight=True,
+    )
+
+    # display(pdsmap)
+    return pdsmap
 
 
 
@@ -979,7 +1042,7 @@ def map():
 # [planning ↓]
 
 # Map (based on city + province, values = (sum, ave, var, max, min))
-# heatmap
+# heatmap()
 
 # Line plot (x-时间序列: 4.移动平均图 Arima  5.时间序列预测 等种种）
 
